.dropdown > .button--secondary,
.row > div > .button--secondary,
.row > div > .button--primary {
  margin: 0;
}

#scoreboardTable_wrapper table,
#scoreboardTable_wrapper th,
#scoreboardTable_wrapper td,
#improvementTable_wrapper table,
#improvementTable_wrapper th,
#improvementTable_wrapper td {
  border: none;
  border-right: 1px solid white;
}

table {
  width: 99%;
}

table tbody td {
  font-size: 15px;
}

table th.fixed-width,
table td.fixed-width {
  max-width: 140px;
  min-width: 140px;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}

#scoreboardTable_wrapper td.scoreboard--started {
  background: #e0004d;
  color: white;
}

#scoreboardTable_wrapper td.scoreboard--completed,
.scoreboard--completed {
  color: #eab502;
  font-size: 24px;
}

#scoreboardTable_wrapper td.scoreboard--completed-secondary {
  color: #fff;
  font-size: 24px;
}

#scoreboardTable_wrapper td.scoreboard--medium-performer {
  background: #f6a500;
}

#scoreboardTable_wrapper td.scoreboard--top-performer {
  background: #b1ba1d;
}

#scoreboardTable_wrapper tr.current-student > td {
  background: #85ddff; /* $color-tertiary-50 */
}
